@@ -1,12 +1,14 @@
-import os, sys
+import os
+import sys
 
 # - good = works
 #   - main = useful
 #   - extra = not very useful
 # - bad = doesn't work
 
-EXTRA = ['console', 'helloworld']
-BAD = ['shoutcast']
+EXTRA = ['helloworld']
+BAD = []
+
 
 def scan():
     all = set(f for f in os.listdir('.') if os.path.isdir(f))
@@ -16,14 +18,16 @@ def scan():
     main = good - extra
     return locals()
 
+
 plugins = scan()
 
+
 def parse(argv):
     if len(argv) == 1:
         return plugins['all']
     return plugins[argv[1]]
 
+
 if __name__ == '__main__':
-    names = list(parse(sys.argv))
-    names.sort()
-    print(' '.join(names))
+    names = sorted(parse(sys.argv))
+    print((' '.join(names)))
